@@ -1,5 +1,6 @@
 from essentials import socket_ops_v2 as socket_ops
 import threading
+from essentials import network_ops
 from .. import Get_Gateway
 
 class Broadcast_Receiver_Server(object):
@@ -35,11 +36,9 @@ class Broadcast_Receiver_Server(object):
         if self.on_data is not None:
             threading.Thread(target=self.on_data, args=[data, connector], daemon=True).start()
 
-
-
 def broadcast_message(message, port, on_response=None, boardcast_ip=None, max_buffer=1024):
     if boardcast_ip == None:
-        boardcast_ip = Get_All_IP_Stat()['ext'][0]['broadcast']
+        boardcast_ip = network_ops.Get_All_IP_Stat()['ext'][0]['broadcast']
 
     connector = socket_ops.UDP_Connector(boardcast_ip, port, on_response, 5, max_buffer=max_buffer)
     try:
